import { z } from 'zod';
export declare const constraintSchema: z.ZodObject<{
    max_path_length: z.ZodOptional<z.ZodNumber>;
    naming_constraints: z.ZodOptional<z.ZodObject<{
        permitted: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        excluded: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        permitted?: string[] | undefined;
        excluded?: string[] | undefined;
    }, {
        permitted?: string[] | undefined;
        excluded?: string[] | undefined;
    }>>;
    allowed_entity_types: z.ZodOptional<z.ZodArray<z.ZodEffects<z.ZodString, string, string>, "many">>;
}, "strip", z.ZodTypeAny, {
    max_path_length?: number | undefined;
    naming_constraints?: {
        permitted?: string[] | undefined;
        excluded?: string[] | undefined;
    } | undefined;
    allowed_entity_types?: string[] | undefined;
}, {
    max_path_length?: number | undefined;
    naming_constraints?: {
        permitted?: string[] | undefined;
        excluded?: string[] | undefined;
    } | undefined;
    allowed_entity_types?: string[] | undefined;
}>;
/**
 *
 * {@link https://openid.net/specs/openid-federation-1_0.html#name-constraints | Constraints}
 *
 * Trust Anchors and Intermediate Entities MAY define constraining criteria that apply to their Subordinates. They are expressed in the constraints claim of a Subordinate Statement, as described in {@link https://openid.net/specs/openid-federation-1_0.html#entity-statement | Section 3}.
 *
 */
export type Constraint = z.input<typeof constraintSchema>;
