import { type EntityConfigurationClaims } from '../entityConfiguration';
import { type VerifyCallback } from '../utils';
export type FetchEntityStatementOptions = {
    iss: string;
    sub: string;
    verifyJwtCallback: VerifyCallback;
    /**
     *
     * The issuers entity configuration
     *
     * If this is not passed in, it will be fetched from the provided `iss` argument.
     *
     */
    issEntityConfiguration?: EntityConfigurationClaims;
    /**
     *
     * Fetch endpoint to get the statements from.
     *
     * If this is not passed in, it will be fetched from the `entityConfiguration.source_endpoint`
     *
     */
    endpoint?: string;
};
export declare const fetchEntityStatement: ({ sub, verifyJwtCallback, iss, endpoint, issEntityConfiguration, }: FetchEntityStatementOptions) => Promise<{
    sub: string;
    jwks: {
        keys: import("zod").objectOutputType<{
            kty: import("zod").ZodString;
            kid: import("zod").ZodString;
            use: import("zod").ZodOptional<import("zod").ZodString>;
            key_ops: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString, "many">>;
            alg: import("zod").ZodOptional<import("zod").ZodString>;
            x5u: import("zod").ZodOptional<import("zod").ZodString>;
            x5c: import("zod").ZodOptional<import("zod").ZodString>;
            x5t: import("zod").ZodOptional<import("zod").ZodString>;
            'x5t#S256': import("zod").ZodOptional<import("zod").ZodString>;
        }, import("zod").ZodTypeAny, "passthrough">[];
    };
    iss: string;
    iat: Date;
    exp: Date;
    authority_hints?: string[] | undefined;
    metadata?: {
        [x: string]: {
            [x: string]: any;
        } | undefined;
    } | undefined;
    metadata_policy?: ({
        [x: string]: any;
    } & {
        [k: string]: unknown;
    }) | undefined;
    constraints?: {
        max_path_length?: number | undefined;
        naming_constraints?: {
            permitted?: string[] | undefined;
            excluded?: string[] | undefined;
        } | undefined;
        allowed_entity_types?: string[] | undefined;
    } | undefined;
    crit?: string[] | undefined;
    metadata_policy_crit?: string[] | undefined;
    trust_marks?: {
        id: string;
        trust_mark: {
            header: Record<string | number, unknown>;
            claims: {
                sub: string;
                iss: string;
                id: string;
                iat: Date;
                exp?: Date | undefined;
                ref?: string | undefined;
            };
            signature: Uint8Array;
        };
    }[] | undefined;
    trust_mark_issuers?: Record<string, string[]> | undefined;
    trust_mark_owners?: Record<string, {
        sub: string;
        jwks: {
            keys: import("zod").objectOutputType<{
                kty: import("zod").ZodString;
                kid: import("zod").ZodString;
                use: import("zod").ZodOptional<import("zod").ZodString>;
                key_ops: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString, "many">>;
                alg: import("zod").ZodOptional<import("zod").ZodString>;
                x5u: import("zod").ZodOptional<import("zod").ZodString>;
                x5c: import("zod").ZodOptional<import("zod").ZodString>;
                x5t: import("zod").ZodOptional<import("zod").ZodString>;
                'x5t#S256': import("zod").ZodOptional<import("zod").ZodString>;
            }, import("zod").ZodTypeAny, "passthrough">[];
        };
    }> | undefined;
    source_endpoint?: string | undefined;
}>;
