"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseJsonWebToken = void 0;
const buffer_1 = require("buffer");
const parseJsonWebToken = (jwt) => {
    const [encodedHeader, encodedClaims, encodedSignature] = jwt.split('.');
    if (!encodedHeader) {
        throw new Error('could not find the header in the JWT');
    }
    if (!encodedClaims) {
        throw new Error('could not find the claims in the JWT');
    }
    if (!encodedSignature) {
        throw new Error('could not find the signature in the JWT');
    }
    const header = JSON.parse(buffer_1.Buffer.from(encodedHeader, 'base64url').toString());
    const claims = JSON.parse(buffer_1.Buffer.from(encodedClaims, 'base64url').toString());
    const signature = new Uint8Array(buffer_1.Buffer.from(encodedSignature, 'base64url'));
    return {
        header,
        claims,
        signature,
        signableInput: new Uint8Array(buffer_1.Buffer.from(`${encodedHeader}.${encodedClaims}`)),
    };
};
exports.parseJsonWebToken = parseJsonWebToken;
//# sourceMappingURL=parseJsonWebToken.js.map