"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createPolicyOperatorSchema = void 0;
const zod_1 = require("zod");
const createPolicyOperatorSchema = (operator) => zod_1.z
    .object({
    [operator.key]: operator.operatorJsonValues.reduce((acc, schema) => acc.or(schema)).optional(),
})
    .passthrough()
    .superRefine((data, ctx) => {
    const dataKeys = Object.keys(data);
    if (dataKeys.includes(operator.key) &&
        dataKeys.some((key) => key !== operator.key && !operator.canBeCombinedWith.includes(key))) {
        ctx.addIssue({
            code: zod_1.z.ZodIssueCode.custom,
            message: `policy operator '${operator.key}' can only be combined with one of: [${operator.canBeCombinedWith.join(', ')}]. keys: [${Object.keys(data).join(',')}]`,
        });
    }
    return data;
});
exports.createPolicyOperatorSchema = createPolicyOperatorSchema;
//# sourceMappingURL=createPolicyOperatorSchema.js.map