"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetcher = void 0;
const url_1 = require("./url");
const validate_1 = require("./validate");
const get = (_a) => __awaiter(void 0, [_a], void 0, function* ({ url, searchParams, responseValidationSchema, requiredContentType, }) {
    // Fetch the url with the search params
    const urlSearchParams = new URLSearchParams(searchParams);
    const urlWithSearchParams = (0, url_1.addSearchParams)(url, urlSearchParams);
    const response = yield global.fetch(urlWithSearchParams, {
        method: 'GET',
    });
    // validate the expected content-type
    if (requiredContentType && response.headers.get('content-type') !== requiredContentType) {
        throw new Error(`received content-type '${response.headers.get('content-type')}' does not equal expected content-type '${requiredContentType}'`);
    }
    // If we pass in a validation schema, we expect JSON output
    if (responseValidationSchema) {
        const json = yield response.json();
        return (0, validate_1.validate)({
            data: json,
            schema: responseValidationSchema,
            errorMessage: 'invalid response from the GET call',
        });
    }
    // If no validation schema is passed in, we expect a string as response
    const text = yield response.text();
    return text;
});
/**
 *
 * @todo make get/post use the same method private internally as changes with apply to both
 *
 */
const post = (_a) => __awaiter(void 0, [_a], void 0, function* ({ url, body, responseValidationSchema, }) {
    const response = yield global.fetch(url, {
        method: 'POST',
        body: body ? JSON.stringify(body) : undefined,
        headers: { 'Content-Type': 'application/json' },
    });
    if (responseValidationSchema) {
        const json = yield response.json();
        return (0, validate_1.validate)({
            data: json,
            schema: responseValidationSchema,
            errorMessage: 'invalid response from a POST call',
        });
    }
    const text = yield response.text();
    return text;
});
exports.fetcher = {
    get,
    post,
};
//# sourceMappingURL=fetch.js.map